@@ -4,7 +4,7 @@ package IOC::Container;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use IOC::Interfaces;
 use IOC::Exceptions;
@@ -133,6 +133,17 @@ sub register {
     $self;
 }
 
+sub unregister {
+    my ($self, $name) = @_;
+    (defined($name)) || throw IOC::InsufficientArguments "You must provide a service name to unregister";
+    (exists ${$self->{services}}{$name}) 
+        || throw IOC::ServiceNotFound "Unknown Service '${name}'"; 
+    my $service = $self->{services}->{$name};
+    $service->removeContainer();    
+    delete $self->{services}->{$name};
+    return $service;
+}
+
 sub get {
     my ($self, $name) = @_;
     (defined($name)) || throw IOC::InsufficientArguments "You must provide a name of the service";
@@ -282,6 +293,10 @@ If C<$service> is not an instance of IOC::Service, or a subclass of it, an B<IOC
 
 If the name of C<$service> already exists, then a B<IOC::ServiceAlreadyExists> exception is thrown.
 
+=item B<unregister ($name)>
+
+Given a C<$name> this will remove the service from the container. If there is no service by that C<$name>, then a B<IOC::ServiceNotFound> exception is thrown.
+
 =item B<get ($name)>
 
 Given a C<$name> this will return the service instance that name corresponds to, if C<$name> is not defined, an exception is thrown.
